"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.encodeCursor = exports.decodeCursor = void 0;
/**
 * Encode a received cursor value into something that can be passed on to the user.
 */
const encodeCursor = cursor => {
  if (!cursor) {
    return undefined;
  }
  cursor = Array.isArray(cursor) ? cursor.map(encodeURIComponent) : encodeURIComponent(cursor);
  try {
    return Buffer.from(JSON.stringify(cursor)).toString("base64");
  } catch (ex) {
    console.error(ex.message);
  }
  return undefined;
};
/**
 * Decode a received value into a Elasticsearch cursor.
 * If no value is received or is not decodable, return undefined.
 */
exports.encodeCursor = encodeCursor;
const decodeCursor = cursor => {
  if (!cursor) {
    return undefined;
  }
  try {
    const value = JSON.parse(Buffer.from(cursor, "base64").toString("ascii"));
    if (Array.isArray(value)) {
      return value.map(decodeURIComponent);
    }
    const decoded = decodeURIComponent(value);
    return decoded ? [decoded] : undefined;
  } catch (ex) {
    console.error(ex.message);
  }
  return undefined;
};
exports.decodeCursor = decodeCursor;

//# sourceMappingURL=cursors.js.map